netapp_ontap.models.aggr_space_efficiency API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.aggr_space_efficiency`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class AggrSpaceEfficiencySchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the AggrSpaceEfficiency object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `auto_adaptive_compression_savings: bool GET`

    Indicates whether or not aggregate has auto adaptive compression savings.

  `cross_volume_background_dedupe: bool GET`

    Indicates whether or not cross volume background deduplication is enabled.

  `cross_volume_dedupe_savings: bool GET`

    Indicates whether or not aggregate has cross volume deduplication savings.

  `cross_volume_inline_dedupe: bool GET`

    Indicates whether or not cross volume inline deduplication is enabled.

  `enable_workload_informed_tsse: bool GET POST PATCH`

    Indicates whether Workload Informed TSSE is enabled on the system.

  `logical_used: Size GET`

    Logical used

  `ratio: float GET`

    Data reduction ratio (logical_used / used)

  `savings: Size GET`

    Space saved by storage efficiencies (logical_used - used)

  `wise_tsse_min_used_capacity_pct: Size GET POST PATCH`

    Minimum amount of used data in aggregate required to trigger cold compression on TSSE volumes.